# Authors

`AI-eXtended Design` has been developed at [**ETH Zurich**](https://ethz.ch/) ([Gramazio Kohler Research](https://gramaziokohler.arch.ethz.ch/), [kfm research](https://kaufmann.ibk.ethz.ch/)) and [**Swiss Data Science Center**](https://www.datascience.ch/), in affiliation with [Design++](https://designplusplus.ethz.ch/).


#### Developers and contributors: 

Aleksandra Apolinarska   
Rafael Bischof   
Gonzalo Casas     
Michael Kraus     
Sophia Kuhn    
Alessandro Maissen   
Romana Rust    
Luis Salamanca     
Konstantinos Tatsis   

together with:   

Matthias Kohler  
Fernando Perez-Cruz  
Walter Kaufmann  

